#
# spec file for package gypsy
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gypsy
Version:        0.9
Release:        lp150.2.5
Summary:        GPS multiplexing daemon
License:        LGPL-2.1
Group:          Hardware/Other
Url:            http://gypsy.freedesktop.org/
Source0:        http://gypsy.freedesktop.org/releases/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM gypsy-g_type_init.patch dimstar@opensuse.org -- Fix build with glib 2.36; g_type_init is deprecated and implicit.
Patch0:         gypsy-g_type_init.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bluez-devel
BuildRequires:  dbus-1-glib-devel
BuildRequires:  glib2-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gudev-1.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gypsy is a GPS multiplexing daemon which allows multiple clients to access
GPS data from multiple GPS sources concurrently.

Without some sort of multiplexing system, a GPS device can only safely be
accessed by one client. In a server situation this may not cause any
problems, but on modern desktop which could potentially have multiple
location aware devices, this could be an issue.

%package -n libgypsy0
Summary:        GPS multiplexing daemon library
Group:          System/Libraries

%description -n libgypsy0
Gypsy is a GPS multiplexing daemon which allows multiple clients to access
GPS data from multiple GPS sources concurrently.

Without some sort of multiplexing system, a GPS device can only safely be
accessed by one client. In a server situation this may not cause any
problems, but on modern desktop which could potentially have multiple
location aware devices, this could be an issue.

%package -n libgypsy-devel
Summary:        Development files for gyps, a GPS multiplexing daemon
Group:          Development/Libraries/C and C++
Requires:       dbus-1-glib-devel
Requires:       libgypsy0 = %{version}

%description -n libgypsy-devel
Gypsy is a GPS multiplexing daemon which allows multiple clients to access
GPS data from multiple GPS sources concurrently.

This subpackage contains the header files for developing
applications that want to make use of libgypsy.

%prep
%setup -q
%patch0 -p1

%build
sed -i "s/-Werror/-Wno-format-security/g" configure*
autoreconf -fiv
%configure \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libgypsy0 -p /sbin/ldconfig
%postun -n libgypsy0 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc AUTHORS COPYING TODO
%{_libexecdir}/gypsy-daemon
%{_sysconfdir}/dbus-1/system.d/*.conf
%config(noreplace) %{_sysconfdir}/gypsy.conf
%{_datadir}/dbus-1/system-services/*.service

%files -n libgypsy0
%defattr(-, root, root)
%doc COPYING.lib
%{_libdir}/*.so.*

%files -n libgypsy-devel
%defattr(-, root, root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/gypsy
%{_datadir}/gtk-doc/html/gypsy
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html

%changelog
* Sat Oct 14 2017 jengelh@inai.de
- Update package description for gypsy-devel.
  Rectify RPM groups.
* Thu Oct 12 2017 mpluskal@suse.com
- Run autoreconf call to silence configure warnings
- Cleanup spec file a bit
- Make building more verbose
* Wed Oct 11 2017 jayvdb@gmail.com
- Add -Wno-format-security to workaround compilation error on Fedora.
- Use %%make_install instead of %%makeinstall
* Wed Mar  2 2016 dimstar@opensuse.org
- Strip "-Werror" out of CFLAGS as set by configure (using sed).
  gypsy is old, unmaintained and when building against modern
  technology results in having build warnings (unused / deprecated
  functions). Fixing the code is not worth the effort, as gypsy
  should be removed.
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf, needed for libQt5Positioning5-32bit
* Thu Apr 18 2013 dimstar@opensuse.org
- Add gypsy-g_type_init.patch: fix build with recent glib versions:
  g_type_init is deprecated and implicit.
* Tue Oct 23 2012 vuntz@opensuse.org
- Update to version 0.9:
  + Add a whitelist for what files Gypsy is allowed to open
    (CVE-2011-0523).
  + Add client side bindings.
  + Add a new Discovery interface.
  + Add a no autoterminate option to daemon.
  + Add a debugging system.
  + Many different bug fixes and build fixes.
- Add pkgconfig(gudev-1.0) BuildRequires: new dependency upstream.
- Remove gypsy-0.8-gcc46.patch, gypsy-CVE-2011-0523.patch,
  gypsy-CVE-2011-0524.patch: all fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh:
  those were only needed for one of the patches above.
* Mon Jul  9 2012 vuntz@opensuse.org
- Add gypsy-CVE-2011-0523.patch: add config file to restrict the
  files that can be read. Fix CVE-2011-0523 and bnc#666839.
- Add gypsy-CVE-2011-0524.patch: use snprintf() to avoid buffer
  overflows. Fix CVE-2011-0524 and bnc#666839.
- Add gnome-common BuildRequires and call to gnome-autogen.sh for
  gypsy-CVE-2011-0523.patch, since it touches the build system.
* Wed May  4 2011 idoenmez@novell.com
- Add gypsy-0.8-gcc46.patch: mark variable as unused to fix gcc 4.6
  compilation
* Fri Aug 13 2010 vuntz@opensuse.org
- Update to version 0.8:
  + Add support for dumping NMEA debug to stdout
  + Fix overeager Garmin device detection
  + Add support for named pipes and FIFOs
  + Fix incorrect use of TCIOFLUSH
  + Add support for setting baud rate on serial devices
  + Log if we are passed an unknown option key
  + Only open TTY devices read-write
  + Support RMC sentences for NMEA < 2.3
  + Add support for the N810's GPS
* Fri Aug  7 2009 vuntz@novell.com
- Update to version 0.7:
  + Support auto-start on the system bus
  + Add Garmin->NMEA converter
  + Fix client unreffing
  + Migrate source to git
- Drop gypsy-dbus-send_destination.patch: not needed anymore.
* Thu Jul 30 2009 vuntz@novell.com
- Use libexecdir instead of libdir.
* Wed Jun 17 2009 vuntz@novell.com
- Initial package.
